@@ -227,7 +227,7 @@ class Jenkins(
         '''
         if __debug__:
             type_hints = typing.get_type_hints(Jenkins.add_base_plugins)
-            check_type(argname="argument base_plugins", value=base_plugins, expected_type=typing.Tuple[type_hints["base_plugins"], ...])
+            check_type(argname="argument base_plugins", value=base_plugins, expected_type=typing.Tuple[type_hints["base_plugins"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addBasePlugins", [*base_plugins]))
 
     @jsii.member(jsii_name="addPlugins")
@@ -238,7 +238,7 @@ class Jenkins(
         '''
         if __debug__:
             type_hints = typing.get_type_hints(Jenkins.add_plugins)
-            check_type(argname="argument plugins", value=plugins, expected_type=typing.Tuple[type_hints["plugins"], ...])
+            check_type(argname="argument plugins", value=plugins, expected_type=typing.Tuple[type_hints["plugins"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addPlugins", [*plugins]))
 
     @jsii.member(jsii_name="addSeedJobs")
@@ -249,7 +249,7 @@ class Jenkins(
         '''
         if __debug__:
             type_hints = typing.get_type_hints(Jenkins.add_seed_jobs)
-            check_type(argname="argument seed_jobs", value=seed_jobs, expected_type=typing.Tuple[type_hints["seed_jobs"], ...])
+            check_type(argname="argument seed_jobs", value=seed_jobs, expected_type=typing.Tuple[type_hints["seed_jobs"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addSeedJobs", [*seed_jobs]))
 
 
@@ -283,7 +283,7 @@ class JenkinsProps:
         :param seed_jobs: List of seed job configuration for Jenkins resource. For more information about seed jobs, please take a look at { @link https://github.com/jenkinsci/job-dsl-plugin/wiki/Tutorial---Using-the-Jenkins-Job-DSL Jenkins Seed Jobs Documentation }. Default: - No seed jobs
         '''
         if isinstance(metadata, dict):
-            metadata = cdk8s.ApiObjectMetadata(**metadata)
+            metadata = ApiObjectMetadata(**metadata)
         if __debug__:
             type_hints = typing.get_type_hints(JenkinsProps.__init__)
             check_type(argname="argument base_plugins", value=base_plugins, expected_type=type_hints["base_plugins"])
